import { defineNuxtModule, createResolver, addPluginTemplate, addTemplate, addImports } from '@nuxt/kit';
import { defu } from 'defu';

const name = "@nuxtjs-alt/http";
const version = "1.3.3";

const CONFIG_KEY = "http";
const module = defineNuxtModule({
  meta: {
    name,
    version,
    configKey: CONFIG_KEY,
    compatibility: {
      nuxt: "^3.0.0-rc.9"
    }
  },
  defaults: {},
  setup(opts, nuxt) {
    const moduleOptions = defu(nuxt.options.runtimeConfig?.public[CONFIG_KEY], opts);
    let defaultHost = moduleOptions.host || process.env.HOST || "localhost";
    const defaultPort = moduleOptions.port || process.env.PORT || 3e3;
    if (defaultHost === "0.0.0.0") {
      defaultHost = "localhost";
    }
    const prefix = moduleOptions.prefix || process.env.PREFIX || "/";
    if (moduleOptions.baseUrl) {
      console.warn("baseUrl is deprecated please use baseURL instead.");
      moduleOptions.baseURL = moduleOptions.baseUrl;
      delete moduleOptions.baseUrl;
    }
    if (moduleOptions.browserBaseUrl) {
      console.warn("browserBaseUrl is deprecated please use browserBaseURL instead.");
      moduleOptions.browserBaseURL = moduleOptions.browserBaseUrl;
      delete moduleOptions.browserBaseUrl;
    }
    const options = defu(moduleOptions, {
      baseURL: `http://${defaultHost}:${defaultPort}${prefix}`,
      browserBaseURL: void 0,
      proxyHeaders: true,
      proxyHeadersIgnore: [
        "accept",
        "connection",
        "cf-connecting-ip",
        "cf-ray",
        "content-length",
        "content-md5",
        "content-type",
        "host",
        "if-modified-since",
        "if-none-match",
        "x-forwarded-host",
        "x-forwarded-port",
        "x-forwarded-proto"
      ],
      serverTimeout: 1e4,
      clientTimeout: 25e3,
      useConflict: false,
      https: false,
      retry: 1,
      headers: {
        accept: "application/json, text/plain, */*"
      },
      credentials: "omit",
      debug: false
    });
    if (typeof options.browserBaseURL === "undefined") {
      options.browserBaseURL = options.baseURL;
    }
    if (options.https === true) {
      const https = (s) => s.replace("http://", "https://");
      options.baseURL = https(options.baseURL);
      options.browserBaseURL = https(options.browserBaseURL);
    }
    const resolver = createResolver(import.meta.url);
    addPluginTemplate({
      src: resolver.resolve("runtime/templates/http.plugin.mjs"),
      filename: "http.plugin.mjs",
      options
    });
    addTemplate({
      getContents: () => getHttpDTS(),
      filename: "http.plugin.d.ts",
      write: true
    });
    const composables = resolver.resolve("runtime/composables");
    addImports([
      { from: composables, name: options.useConflict ? "useFetch" : "useHttp" },
      { from: composables, name: options.useConflict ? "useLazyFetch" : "useLazyHttp" }
    ]);
  }
});
function getHttpDTS() {
  return `import type { Plugin } from '#app'
import { FetchInstance } from '@refactorjs/ofetch'

declare const _default: Plugin<{
    http: FetchInstance;
}>;

export default _default;
`;
}

export { module as default };
